summaryrefslogtreecommitdiff
path: root/chromium/ui/login/account_picker/md_screen_account_picker.js
diff options
context:
space:
mode:
authorAllan Sandfeld Jensen <allan.jensen@qt.io>2017-11-20 10:33:36 +0100
committerAllan Sandfeld Jensen <allan.jensen@qt.io>2017-11-22 11:45:12 +0000
commitbe59a35641616a4cf23c4a13fa0632624b021c1b (patch)
tree9da183258bdf9cc413f7562079d25ace6955467f /chromium/ui/login/account_picker/md_screen_account_picker.js
parentd702e4b6a64574e97fc7df8fe3238cde70242080 (diff)
downloadqtwebengine-chromium-be59a35641616a4cf23c4a13fa0632624b021c1b.tar.gz
BASELINE: Update Chromium to 62.0.3202.101
Change-Id: I2d5eca8117600df6d331f6166ab24d943d9814ac Reviewed-by: Alexandru Croitor <alexandru.croitor@qt.io>
Diffstat (limited to 'chromium/ui/login/account_picker/md_screen_account_picker.js')
-rw-r--r--chromium/ui/login/account_picker/md_screen_account_picker.js12
1 files changed, 6 insertions, 6 deletions
diff --git a/chromium/ui/login/account_picker/md_screen_account_picker.js b/chromium/ui/login/account_picker/md_screen_account_picker.js
index fbd0d800d60..81741683f54 100644
--- a/chromium/ui/login/account_picker/md_screen_account_picker.js
+++ b/chromium/ui/login/account_picker/md_screen_account_picker.js
@@ -32,7 +32,7 @@ login.createScreen('AccountPickerScreen', 'account-picker', function() {
'removeUserPodFingerprintIcon',
'setPinEnabledForUser',
'setAuthType',
- 'setTouchViewState',
+ 'setTabletModeState',
'setPublicSessionDisplayName',
'setPublicSessionLocales',
'setPublicSessionKeyboardLayouts',
@@ -146,7 +146,7 @@ login.createScreen('AccountPickerScreen', 'account-picker', function() {
// again already. If that happens, ignore the onShow() call.
return;
}
- chrome.send('getTouchViewState');
+ chrome.send('getTabletModeState');
if (!this.firstShown_) return;
this.firstShown_ = false;
@@ -348,11 +348,11 @@ login.createScreen('AccountPickerScreen', 'account-picker', function() {
},
/**
* Sets the state of touch view mode.
* @param {boolean} isTouchViewEnabled true if the mode is on.
*/
- setTouchViewState: function(isTouchViewEnabled) {
- $('pod-row').setTouchViewState(isTouchViewEnabled);
+ setTabletModeState: function(isTabletModeEnabled) {
+ $('pod-row').setTabletModeState(isTabletModeEnabled);
},
/**
@@ -348,11 +348,11 @@ login.createScreen('AccountPickerScreen', 'account-picker', function() {
},
/**
- * Sets the state of touch view mode.
- * @param {boolean} isTouchViewEnabled true if the mode is on.
+ * Sets the state of tablet mode.
+ * @param {boolean} isTabletModeEnabled true if the mode is on.
*/